@@ -15,7 +15,7 @@ DBIx::DBO - An OO interface to SQL queries and results.  Easily constructs SQL q
 
 =cut
 
-our $VERSION = '0.01_02';
+our $VERSION = '0.01_03';
 
 =head1 SYNOPSIS
 
@@ -56,19 +56,16 @@ our $VERSION = '0.01_02';
       $row->delete if $record->{id} == 27;
   }
 
-  # Join tables (INNER JOIN)
-  my ($query, $table1, $table2, $table3) = $dbo->query('my_table', 't2', 'third');
-  $query->join_on($table2 ** 'parent_id', '=', $table3 ** 'child_id');
-
-  # Join tables (LEFT JOIN)
-  my ($query, $table1) = $dbo->query('my_table');
-  my $table2 = $query->join_table('another_table', 'LEFT');
-  $query->join_on($table2 ** 'parent_id', '=', $table1 ** 'child_id');
-
 =head1 DESCRIPTION
 
 This module provides a convenient and efficient way to access a database. It can construct queries for you and returns the results in easy to use methods.
 
+Once you've created a C<DBIx::DBO> object using one or both of C<connect> or C<connect_readonly>, you can begin creating C<DBIx::DBO::Query> objects. These are the "workhorse" objects, they encapsulate an entire query with JOINs, WHERE clauses, etc. You need not have to know about what created the Query to be able to use or modify it. This makes it valuable in environments like mod_perl or large projects that prefer an object oreinted approach to data.
+
+The Query is only automatically executed when the data is requested. This is to make it possible to minimise lookups that may not be needed or to delay them as late as possible.
+
+The C<DBIx::DBO::Row> object returned can be treated as both an arrayref or a hashref. The data is aliased for efficient use of memory. C<Row> objects can be updated or deleted, even when created by JOINs (If the DB supports it).
+
 =head1 METHODS
 
 =cut
@@ -88,31 +85,6 @@ sub import {
     }
 }
 
-=head2 config
-
-  $global_setting = DBIx::DBO->config($option);
-  DBIx::DBO->config($option => $global_setting);
-  $dbo_setting = $dbo->config($option);
-  $dbo->config($option => $dbo_setting);
-
-Get or set the global or C<DBIx::DBO> config settings.
-When setting an option, the previous value is returned.
-
-=cut
-
-sub config {
-    my $me = shift;
-    my $opt = shift;
-    unless (blessed $me) {
-        my $val = $Config{$opt};
-        $Config{$opt} = shift if @_;
-        return $val;
-    }
-    my $val = $me->{Config}{$opt} // $Config{$opt};
-    $me->{Config}{$opt} = shift if @_;
-    return $val;
-}
-
 =head2 connect
 
   $dbo = DBIx::DBO->connect($data_source, $username, $password, \%attr)
@@ -259,11 +231,11 @@ sub _bless_dbo {
 
 =head2 dbh
 
-The read-write DBI handle.
+The read-write C<DBI> handle.
 
 =head2 rdbh
 
-The read-only DBI handle, or if there is no read-only connection, the read-write DBI handle.
+The read-only C<DBI> handle, or if there is no read-only connection, the read-write C<DBI> handle.
 
 =head2 do
 
@@ -271,7 +243,7 @@ The read-only DBI handle, or if there is no read-only connection, the read-write
   $dbo->do($statement, \%attr) or die $dbo->dbh->errstr;
   $dbo->do($statement, \%attr, @bind_values) or die ...
 
-This provides access to DBI C<do> method. It defaults to using the read-write DBI handle.
+This provides access to L<DBI-E<gt>do|DBI/"do"> method. It defaults to using the read-write C<DBI> handle.
 
 =cut
 
@@ -293,19 +265,19 @@ sub rdbh {
 
   $dbo->selectrow_array($statement, \%attr, @bind_values);
 
-This provides access to DBI C<selectrow_array> method.
+This provides access to L<DBI-E<gt>selectrow_array|DBI/"selectrow_array"> method.
 
 =head2 selectrow_arrayref
 
   $dbo->selectrow_arrayref($statement, \%attr, @bind_values);
 
-This provides access to DBI C<selectrow_arrayref> method.
+This provides access to L<DBI-E<gt>selectrow_arrayref|DBI/"selectrow_arrayref"> method.
 
 =head2 selectall_arrayref
 
   $dbo->selectall_arrayref($statement, \%attr, @bind_values);
 
-This provides access to DBI C<selectall_arrayref> method.
+This provides access to L<DBI-E<gt>selectall_arrayref|DBI/"selectall_arrayref"> method.
 
 =cut
 
@@ -402,7 +374,8 @@ sub table_info {
   $dbo->table([$schema, $table]);
   $dbo->table($table_object);
 
-Create a new table object for the table specified.
+Create and return a new L<DBIx::DBO::Table> object.
+Tables can be specified by their name or an arrayref of schema and table name or a L<DBIx::DBO::Table> object.
 
 =cut
 
@@ -417,9 +390,11 @@ sub table {
   $dbo->query([$schema, $table], ...);
   $dbo->query($table_object, ...);
 
-Create a new query object from the tables specified.
-In scalar context, just the query object will be returned.
-In list context table objects will also be returned for each table specified.
+Create a new L<DBIx::DBO::Query> object from the tables specified.
+In scalar context, just the C<Query> object will be returned.
+In list context, the C<Query> object and L<DBIx::DBO::Table> objects will be returned for each table specified.
+
+  my ($query, $table1, $table2) = $dbo->query(['my_schema', 'my_table'], 'my_other_table');
 
 =cut
 
@@ -433,7 +408,7 @@ sub query {
   $dbo->row($table_object);
   $dbo->row($query_object);
 
-Create a new row object.
+Create and return a new L<DBIx::DBO::Row> object.
 
 =cut
 
@@ -462,6 +437,45 @@ sub disconnect {
     return;
 }
 
+=head2 config
+
+  $global_setting = DBIx::DBO->config($option);
+  DBIx::DBO->config($option => $global_setting);
+  $dbo_setting = $dbo->config($option);
+  $dbo->config($option => $dbo_setting);
+
+Get or set the global or C<DBIx::DBO> config settings.
+When setting an option, the previous value is returned.
+
+Options include:
+=over
+=item QuoteIdentifier
+Boolean setting to control quoting of SQL identifiers (schema, table and column names).
+Defaults to 1.
+=item _Debug_SQL
+Set to a number 0 - 2 to warn with varying levels of debugging for each SQL command executed.
+Defaults to 0.
+=back
+
+Global options can also be set when C<use>'ing the module:
+
+  use DBIx::DBO QuoteIdentifier => 0, _Debug_SQL => 1;
+
+=cut
+
+sub config {
+    my $me = shift;
+    my $opt = shift;
+    unless (blessed $me) {
+        my $val = $Config{$opt};
+        $Config{$opt} = shift if @_;
+        return $val;
+    }
+    my $val = $me->{Config}{$opt} // $Config{$opt};
+    $me->{Config}{$opt} = shift if @_;
+    return $val;
+}
+
 sub DESTROY {
     undef %{$_[0]};
 }
@@ -472,48 +486,44 @@ __END__
 
 =head1 AUTHOR
 
-Vernon Lyon, C<< <vlyon at cpan.org> >>
-
-=head1 BUGS
-
-Please report any bugs or feature requests to C<bug-dbix-dbo at rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBIx-DBO>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
-
+Vernon Lyon, C<< <vlyon AT cpan.org> >>
 
 =head1 SUPPORT
 
-You can find documentation for this module with the perldoc command.
-
-    perldoc DBIx::DBO
-
-
-You can also look for information at:
+You can find more information for this module at:
 
 =over 4
 
 =item * RT: CPAN's request tracker
-
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=DBIx-DBO>
 
 =item * AnnoCPAN: Annotated CPAN documentation
-
 L<http://annocpan.org/dist/DBIx-DBO>
 
 =item * CPAN Ratings
-
 L<http://cpanratings.perl.org/d/DBIx-DBO>
 
 =item * Search CPAN
-
 L<http://search.cpan.org/dist/DBIx-DBO>
 
 =back
 
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-dbix-dbo AT rt.cpan.org>, or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBIx-DBO>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009 Vernon Lyon, all rights reserved.
 
-This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This package is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+
+
+=head1 SEE ALSO
+
+DBI, DBIx::SearchBuilder.
 
 
 =cut
